==> qtjambi-uic-6.2.12-sources.jar: io/qt/uic/ui4/DomLayoutItem.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class DomLayoutItem</p>
 */
public class DomLayoutItem extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum DomLayoutItem::Kind</p>
     */
    public enum Kind implements QtEnumerator {
        Unknown(0),
        Widget(1),
        Layout(2),
        Spacer(3);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Kind(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static Kind resolve(int value) {
            switch (value) {
            case 0: return Unknown;
            case 1: return Widget;
            case 2: return Layout;
            case 3: return Spacer;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public DomLayoutItem(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomLayoutItem instance);
    
    @QtUninvokable
    public final java.lang.@NonNull String attributeAlignment(){
        return attributeAlignment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeAlignment_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final int attributeColSpan(){
        return attributeColSpan_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int attributeColSpan_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final int attributeColumn(){
        return attributeColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int attributeColumn_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final int attributeRow(){
        return attributeRow_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int attributeRow_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final int attributeRowSpan(){
        return attributeRowSpan_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int attributeRowSpan_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeAlignment(){
        clearAttributeAlignment_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeAlignment_native(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeColSpan(){
        clearAttributeColSpan_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeColSpan_native(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeColumn(){
        clearAttributeColumn_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeColumn_native(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeRow(){
        clearAttributeRow_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeRow_native(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeRowSpan(){
        clearAttributeRowSpan_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeRowSpan_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomLayout elementLayout(){
        return elementLayout_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomLayout elementLayout_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomSpacer elementSpacer(){
        return elementSpacer_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomSpacer elementSpacer_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomWidget elementWidget(){
        return elementWidget_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomWidget elementWidget_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeAlignment(){
        return hasAttributeAlignment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeAlignment_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeColSpan(){
        return hasAttributeColSpan_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeColSpan_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeColumn(){
        return hasAttributeColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeColumn_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeRow(){
        return hasAttributeRow_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeRow_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeRowSpan(){
        return hasAttributeRowSpan_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeRowSpan_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.DomLayoutItem.@NonNull Kind kind(){
        return io.qt.uic.ui4.DomLayoutItem.Kind.resolve(kind_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int kind_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @QtUninvokable
    public final void setAttributeAlignment(java.lang.@NonNull String a){
        setAttributeAlignment_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeAlignment_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @QtUninvokable
    public final void setAttributeColSpan(int a){
        setAttributeColSpan_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeColSpan_native_int(long __this__nativeId, int a);
    
    @QtUninvokable
    public final void setAttributeColumn(int a){
        setAttributeColumn_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeColumn_native_int(long __this__nativeId, int a);
    
    @QtUninvokable
    public final void setAttributeRow(int a){
        setAttributeRow_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeRow_native_int(long __this__nativeId, int a);
    
    @QtUninvokable
    public final void setAttributeRowSpan(int a){
        setAttributeRowSpan_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeRowSpan_native_int(long __this__nativeId, int a);
    
    @QtUninvokable
    public final void setElementLayout(io.qt.uic.ui4.@Nullable DomLayout a){
        setElementLayout_native_DomLayout_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementLayout_native_DomLayout_ptr(long __this__nativeId, long a);
    
    @QtUninvokable
    public final void setElementSpacer(io.qt.uic.ui4.@Nullable DomSpacer a){
        setElementSpacer_native_DomSpacer_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementSpacer_native_DomSpacer_ptr(long __this__nativeId, long a);
    
    @QtUninvokable
    public final void setElementWidget(io.qt.uic.ui4.@Nullable DomWidget a){
        setElementWidget_native_DomWidget_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementWidget_native_DomWidget_ptr(long __this__nativeId, long a);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomLayout takeElementLayout(){
        return takeElementLayout_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomLayout takeElementLayout_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomSpacer takeElementSpacer(){
        return takeElementSpacer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomSpacer takeElementSpacer_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomWidget takeElementWidget(){
        return takeElementWidget_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomWidget takeElementWidget_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected DomLayoutItem(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.3.4-sources.jar: io/qt/uic/ui4/DomLayoutItem.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomLayoutItem</p>
 */
public class DomLayoutItem extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum DomLayoutItem::Kind</p>
     */
    public enum Kind implements io.qt.QtEnumerator {
        Unknown(0),
        Widget(1),
        Layout(2),
        Spacer(3);

        private Kind(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static Kind resolve(int value) {
            switch (value) {
            case 0: return Unknown;
            case 1: return Widget;
            case 2: return Layout;
            case 3: return Spacer;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public DomLayoutItem(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomLayoutItem instance);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeAlignment(){
        return attributeAlignment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeAlignment_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int attributeColSpan(){
        return attributeColSpan_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int attributeColSpan_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int attributeColumn(){
        return attributeColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int attributeColumn_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int attributeRow(){
        return attributeRow_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int attributeRow_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int attributeRowSpan(){
        return attributeRowSpan_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int attributeRowSpan_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeAlignment(){
        clearAttributeAlignment_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeAlignment_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeColSpan(){
        clearAttributeColSpan_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeColSpan_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeColumn(){
        clearAttributeColumn_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeColumn_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeRow(){
        clearAttributeRow_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeRow_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeRowSpan(){
        clearAttributeRowSpan_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeRowSpan_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomLayout elementLayout(){
        return elementLayout_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomLayout elementLayout_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomSpacer elementSpacer(){
        return elementSpacer_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomSpacer elementSpacer_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomWidget elementWidget(){
        return elementWidget_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomWidget elementWidget_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeAlignment(){
        return hasAttributeAlignment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeAlignment_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeColSpan(){
        return hasAttributeColSpan_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeColSpan_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeColumn(){
        return hasAttributeColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeColumn_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeRow(){
        return hasAttributeRow_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeRow_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeRowSpan(){
        return hasAttributeRowSpan_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeRowSpan_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomLayoutItem.Kind kind(){
        return io.qt.uic.ui4.DomLayoutItem.Kind.resolve(kind_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int kind_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeAlignment(java.lang.String a){
        setAttributeAlignment_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeAlignment_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setAttributeColSpan(int a){
        setAttributeColSpan_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeColSpan_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setAttributeColumn(int a){
        setAttributeColumn_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeColumn_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setAttributeRow(int a){
        setAttributeRow_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeRow_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setAttributeRowSpan(int a){
        setAttributeRowSpan_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeRowSpan_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementLayout(io.qt.uic.ui4.DomLayout a){
        setElementLayout_native_DomLayout_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementLayout_native_DomLayout_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final void setElementSpacer(io.qt.uic.ui4.DomSpacer a){
        setElementSpacer_native_DomSpacer_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementSpacer_native_DomSpacer_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final void setElementWidget(io.qt.uic.ui4.DomWidget a){
        setElementWidget_native_DomWidget_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementWidget_native_DomWidget_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomLayout takeElementLayout(){
        return takeElementLayout_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomLayout takeElementLayout_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomSpacer takeElementSpacer(){
        return takeElementSpacer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomSpacer takeElementSpacer_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomWidget takeElementWidget(){
        return takeElementWidget_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomWidget takeElementWidget_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, "");
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomLayoutItem(QPrivateConstructor p) { super(p); } 
    
}
